AWS Distro For OpenTelemetry Python Distro - Custom Genesis Build
==================================================================

Installation
------------

::

    pip install yiyuanh-test-fork-aws-opentelemetry-distro


This package provides a custom fork of the Amazon Web Services distribution of the OpenTelemetry Python Instrumentation with Genesis SDK defaults, which allows for auto-instrumentation of Python applications.

**Note:** This is a custom build for private beta testing. For the official AWS OpenTelemetry Distro, use ``pip install aws-opentelemetry-distro``.

References
----------

* `OpenTelemetry Project <https://opentelemetry.io/>`_
* `Example using opentelemetry-distro <https://opentelemetry.io/docs/instrumentation/python/distro/>`_
